
:orphan:

Whisper
=======

Automatically generated index page for Whisper:

.. raw:: html

   <ul>

   </ul>
     <a href="whisperindex.html">
       <p style="margin-bottom: 5px"><b>Whisper-Index</b> <span style="margin-left: 10px; color: darkgray">WhisperIndex</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="whisperindex.html" style="margin-bottom: 10px">
       v<b>2.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="whisperalign.html">
       <p style="margin-bottom: 5px"><b>Whisper-Align</b> <span style="margin-left: 10px; color: darkgray">whisperAlign</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="whisperalign.html" style="margin-bottom: 10px">
       v<b>2.0</b>
     </a></p>
     </a>
     <hr />
         

